
# Android端微信小程序自动化测试库

## 已实现的功能

* 微信登录
* 登录后的弹窗处理
* 打开小程序接口
* 微信官放demo小程序封装


## 安装

```
$ pip install wxmplib -i http://pypi.dq.oa.com/simple --trusted-host=pypi.dq.oa.com
```

## demo示例

参见[demo/mp_demo.py](blob/master/demo/mp_demo.py)